import java.lang.reflect.*;

/**
 * The class takes a class name as a command line argument and iterates 
 * over all the methods of the named class attempting to invoke each method 
 * that is annotated with the <code>Test</cpde> annotation type. The reflective 
 * query to find out if a method has a Test annotation is highlighted in green. 
 * If a test method invocation throws an exception, the test is deemed to have 
 * failed, and a failure report is printed. Finally, a summary is printed showing 
 * the number of tests that passed and failed. 
 */

public class RunTests {
	public static void main(String[] args) throws Exception {
		int passed = 0, failed = 0;
		for (Method m : Class.forName(args[0]).getMethods()) {
			if (m.isAnnotationPresent(Test.class)) {
				try {
					m.invoke(null);
					passed++;
				} catch (Throwable ex) {
					System.out.printf("Test %s failed: %s %n", m, ex.getCause());
					failed++;
				}
			}
		}
		System.out.printf("Passed: %d, Failed %d%n", passed, failed);
	}
}

